local ipOps = require "ipOps"
local http = require "http"
local nmap = require "nmap"
local shortport = require "shortport"
local stdnse = require "stdnse"
local table = require "table"

description = [[
Grabs the Google tracking code and HTTP title from the site
]]

---
-- @output
-- Nmap scan report for digininja.org (217.147.180.164)
-- Host is up (0.025s latency).
-- rDNS record for 217.147.180.164: www.digininja.org
-- PORT   STATE SERVICE
-- 80/tcp open  http
-- | http-tracker_tracking: 
-- |   Tracking code: 7503551
-- |_  Page title: DigiNinja
-- 
--@args path The path to request, such as <code>/index.php</code>. Default <code>/</code>. 

author = "Robin Wood"

license = "Creative Commons Attribution-Share Alike Licence"

categories = {"discovery", "safe"}

portrule = shortport.http

function trim(s)
	return (s:gsub("^%s*(.-)%s*$", "%1"))
end

action = function(host, port)
	local path = stdnse.get_script_args(SCRIPT_NAME..".path") or "/"
	local useget = stdnse.get_script_args(SCRIPT_NAME..".useget")
	local request_type = "GET"
	local result

	result = http.get(host, port, path, { redirect_ok = function(host,port) 
			local c = 5
			return function(url)
				stdnse.print_debug(1, "Redirecting to " .. url.host .. " on port " .. (url.port or 80))
				if ( c==0 ) then return false end
					c = c - 1
					return true
				end
		end
		}
	)

	if(result == nil) then
		if(nmap.debugging() > 0) then
			return "ERROR: Request failed"
		else
			return nil
		end
	end

	if(result.body == nil) then
		if(nmap.debugging() > 0) then
			return "ERROR: GET request didn't return proper content"
		else
			return nil
		end
	end

	-- Have to have - as [-] otherwise it messes things up, I think it affects the A
	-- making it appear to be a B for some reason

	local track_code = string.match(result.body, 'UA[-]([0-9]*)[-][0-9]*')
	if track_code ~= nil then
		local output = {}

		table.insert (output, "Tracking code: " .. track_code)
		stdnse.print_debug(1, "The tracking code is " .. track_code)

		-- Can't find a better way to do this in a case insensitive way
		local page_title = string.match(result.body, "<[tT][iI][tT][lL][eE]>(.*)</[tT][iI][tT][lL][eE]>")
		
		if (page_title ~= nil) then
			table.insert (output, "Page title: " .. trim(page_title))
		end

		return stdnse.format_output(true, output)
	else
		stdnse.print_debug(1, "No tracking")
		return nil
		--return stdnse.format_output(true, "No tracking")
	end
end
