#!/usr/bin/env ruby

# == Tracker Tracking
#
# A tool to parse the output ot my http-tracker_tracking.nse nmap script.
#
# For more information see http://www.digininja.org/projects/tracker_tracking.php
#
# == Usage
#
# parse_tracking.rb <input .nmap file> <output .csv file>
#
# Author:: Robin Wood (robin@digininja.org)
# Copyright:: Copyright (c) Robin Wood 2013
# Licence:: Creative Commons Attribution-Share Alike Licence
#

require "csv"

=begin

This is a smple block that will be parsed

Nmap scan report for tumblr.com (66.6.36.12)
Host is up (0.093s latency).
PORT   STATE SERVICE
80/tcp open  http
| http-tracker_tracking: 
|   Tracking code: 97144
|_  Page title: Tumblr

=end

class Block
	attr_accessor :code
	attr_accessor :url
	attr_accessor :title

	def to_s
		str = "Tracking Code: #{@code}\n"
		str += "URL: #{@url}\n"
		str += "Title: #{@title}\n\n"
		return str
	end
end

if ARGV.length != 2
	puts "parse_tracking 1.0 Robin Wood (robin@digininja.org) (www.digininja.org)

Usage: parse_tracking.rb <input .nmap file> <output .csv file>

"
	exit
end

if !File.exists?(ARGV[0])
	puts "Could not open input file"
	puts
	exit
end

f = File.open(ARGV[0], "r")

b = Block.new

results = {}

i = 0
f.each_line do |line|
	line.chomp!
	if line == ""
		if !b.code.nil?
			#puts i.to_s
			#puts b.inspect

			if !results.has_key?(b.code)
				results[b.code] = []
			end

			results[b.code] << b
		end

		b = Block.new
	end

	if line =~ /Nmap scan report for ([^ ]*)/
		b.url = $1
	end

	if line =~ /Page title: (.*)/
		b.title = $1
	end
	if line =~ /Tracking code: (.*)/
		code = $1
		b.code = code.to_i
	end

	i += 1
end

f.close

begin
	csv = CSV.open(ARGV[1], "w") do |csv|
		# this will sort the results hash based on the code
		results.sort.map do |code, block_arr|
			puts code
			block_arr.each do |block|
				puts block.url
				puts block.title
				csv << [code, block.url, block.title]
			end
			puts
		end
	end
rescue Errno::EACCES
	puts "You don't have permission to write to the output file"
	puts
	exit
rescue
	puts "There was a problem writting the CSV file"
	puts
	exit
end
